==> zio-aws-sagemaker_2.12-7.21.15.1-sources.jar: zio/aws/sagemaker/model/CandidateArtifactLocations.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{
  BacktestResultsLocation,
  ModelInsightsLocation,
  ExplainabilityLocation
}
import scala.jdk.CollectionConverters._
final case class CandidateArtifactLocations(
    explainability: ExplainabilityLocation,
    modelInsights: Optional[ModelInsightsLocation] = Optional.Absent,
    backtestResults: Optional[BacktestResultsLocation] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.CandidateArtifactLocations = {
    import CandidateArtifactLocations.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.CandidateArtifactLocations
      .builder()
      .explainability(
        ExplainabilityLocation.unwrap(explainability): java.lang.String
      )
      .optionallyWith(
        modelInsights.map(value =>
          ModelInsightsLocation.unwrap(value): java.lang.String
        )
      )(_.modelInsights)
      .optionallyWith(
        backtestResults.map(value =>
          BacktestResultsLocation.unwrap(value): java.lang.String
        )
      )(_.backtestResults)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.CandidateArtifactLocations.ReadOnly =
    zio.aws.sagemaker.model.CandidateArtifactLocations.wrap(buildAwsValue())
}
object CandidateArtifactLocations {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.CandidateArtifactLocations
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.CandidateArtifactLocations =
      zio.aws.sagemaker.model.CandidateArtifactLocations(
        explainability,
        modelInsights.map(value => value),
        backtestResults.map(value => value)
      )
    def explainability: ExplainabilityLocation
    def modelInsights: Optional[ModelInsightsLocation]
    def backtestResults: Optional[BacktestResultsLocation]
    def getExplainability: ZIO[Any, Nothing, ExplainabilityLocation] =
      ZIO.succeed(explainability)
    def getModelInsights: ZIO[Any, AwsError, ModelInsightsLocation] =
      AwsError.unwrapOptionField("modelInsights", modelInsights)
    def getBacktestResults: ZIO[Any, AwsError, BacktestResultsLocation] =
      AwsError.unwrapOptionField("backtestResults", backtestResults)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.CandidateArtifactLocations
  ) extends zio.aws.sagemaker.model.CandidateArtifactLocations.ReadOnly {
    override val explainability: ExplainabilityLocation =
      zio.aws.sagemaker.model.primitives
        .ExplainabilityLocation(impl.explainability())
    override val modelInsights: Optional[ModelInsightsLocation] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modelInsights())
        .map(value =>
          zio.aws.sagemaker.model.primitives.ModelInsightsLocation(value)
        )
    override val backtestResults: Optional[BacktestResultsLocation] =
      zio.aws.core.internal
        .optionalFromNullable(impl.backtestResults())
        .map(value =>
          zio.aws.sagemaker.model.primitives.BacktestResultsLocation(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.CandidateArtifactLocations
  ): zio.aws.sagemaker.model.CandidateArtifactLocations.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_2.13-5.17.164.1-sources.jar: zio/aws/sagemaker/model/CandidateArtifactLocations.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{
  ModelInsightsLocation,
  ExplainabilityLocation
}
import scala.jdk.CollectionConverters._
final case class CandidateArtifactLocations(
    explainability: ExplainabilityLocation,
    modelInsights: Optional[ModelInsightsLocation] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.CandidateArtifactLocations = {
    import CandidateArtifactLocations.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.CandidateArtifactLocations
      .builder()
      .explainability(
        ExplainabilityLocation.unwrap(explainability): java.lang.String
      )
      .optionallyWith(
        modelInsights.map(value =>
          ModelInsightsLocation.unwrap(value): java.lang.String
        )
      )(_.modelInsights)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.CandidateArtifactLocations.ReadOnly =
    zio.aws.sagemaker.model.CandidateArtifactLocations.wrap(buildAwsValue())
}
object CandidateArtifactLocations {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.CandidateArtifactLocations
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.CandidateArtifactLocations =
      zio.aws.sagemaker.model.CandidateArtifactLocations(
        explainability,
        modelInsights.map(value => value)
      )
    def explainability: ExplainabilityLocation
    def modelInsights: Optional[ModelInsightsLocation]
    def getExplainability: ZIO[Any, Nothing, ExplainabilityLocation] =
      ZIO.succeed(explainability)
    def getModelInsights: ZIO[Any, AwsError, ModelInsightsLocation] =
      AwsError.unwrapOptionField("modelInsights", modelInsights)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.CandidateArtifactLocations
  ) extends zio.aws.sagemaker.model.CandidateArtifactLocations.ReadOnly {
    override val explainability: ExplainabilityLocation =
      zio.aws.sagemaker.model.primitives
        .ExplainabilityLocation(impl.explainability())
    override val modelInsights: Optional[ModelInsightsLocation] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modelInsights())
        .map(value =>
          zio.aws.sagemaker.model.primitives.ModelInsightsLocation(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.CandidateArtifactLocations
  ): zio.aws.sagemaker.model.CandidateArtifactLocations.ReadOnly = new Wrapper(
    impl
  )
}
